package iut.echec.moteur.plateau;

import iut.echec.moteur.joueurs.*;
import iut.echec.moteur.pieces.*;

public class Echiquier implements IEchiquier {
	
    private ICase[] cases;
    private IJoueur blanc, noir;

    public Echiquier()
    {
        this.cases = new ICase[64];
        this.blanc = new Blanc();
        this.noir = new Noir();
    }

    /* (non-Javadoc)
	 * @see fr.iut.moteur.plateau.IEchiquier#initialiser()
	 */
    @Override
	public void initialiser()
    {
        int taille = this.cases.length;
        for (int i = 0; i < taille / 2; i++)
        {
            int oppose = taille - i - 1;
            this.cases[i] = new Case(i);
            this.cases[oppose] = new Case(oppose);
            switch (i)
            {
                case 0 :
                case 7 :
                    this.cases[i].setPiece(new Tour(blanc,this));
                    this.cases[oppose].setPiece(new Tour(noir,this));
                    break;
                case 1 :
                case 6 :
                    this.cases[i].setPiece(new Cavalier(blanc,this));
                    this.cases[oppose].setPiece(new Cavalier(noir,this));
                    break;
                case 2 :
                case 5 :
                    this.cases[i].setPiece(new Fou(blanc,this));
                    this.cases[oppose].setPiece(new Fou(noir,this));
                    break;                    
                case 3 : 
                   this.cases[i].setPiece(new Roi(blanc, this)); 
                   this.cases[oppose].setPiece(new Reine(noir, this)); 
                   break;
                case 4 :
                   this.cases[i].setPiece(new Reine(blanc, this));
                   this.cases[oppose].setPiece(new Roi(noir, this));
                default :
                    if (i > 7 && i < 16)
                    {
                        this.cases[i].setPiece(new Pion(blanc, this));
                        this.cases[oppose].setPiece(new Pion(noir, this));
                    }
                    break;
            }
        }
    }

    /* (non-Javadoc)
	 * @see fr.iut.moteur.plateau.IEchiquier#afficher()
	 */
    @Override
	public void afficher()
    {
        for (int i = this.cases.length - 1; i >= 0; i--)
        {
            String txt;
            if (this.cases[i].estVide())
            {
                txt = "v";
            }
            else
            {
                txt = this.cases[i].getPiece().nomPiece();
            }
            if ((i + 1) % 8 == 0)
                System.out.println();
            System.out.print(txt + " ");
        }
    }

    /* (non-Javadoc)
	 * @see fr.iut.moteur.plateau.IEchiquier#getPositionPiece(fr.iut.moteur.pieces.IPiece)
	 */
    @Override
	public int getPositionPiece(IPiece piece)
    {
        for (int i = 0; i < this.cases.length; i++)
        {
            if (this.cases[i].getPiece() == piece)
                return i;
        }
        return -1;
    }
}
